=== modified file 'NEWS'
--- NEWS	2010-08-12 03:02:14 +0000
+++ NEWS	2010-08-13 07:33:28 +0000
@@ -30,6 +30,12 @@
 API Changes
 ***********
 
+Internals
+*********
+
+* Remove used and broken code path in ``BranchInitHookParams.__repr__``.
+  (Andrew Bennetts)
+
 Testing
 *******
 

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2010-08-11 10:13:08 +0000
+++ bzrlib/branch.py	2010-08-13 07:32:06 +0000
@@ -1958,12 +1958,7 @@
         return self.__dict__ == other.__dict__
 
     def __repr__(self):
-        if self.branch:
-            return "<%s of %s>" % (self.__class__.__name__, self.branch)
-        else:
-            return "<%s of format:%s bzrdir:%s>" % (
-                self.__class__.__name__, self.branch,
-                self.format, self.bzrdir)
+        return "<%s of %s>" % (self.__class__.__name__, self.branch)
 
 
 class SwitchHookParams(object):

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2010-06-20 21:14:49 +0000
+++ bzrlib/tests/test_branch.py	2010-08-13 07:32:06 +0000
@@ -552,6 +552,15 @@
         self.assertTrue(hasattr(params, 'bzrdir'))
         self.assertTrue(hasattr(params, 'branch'))
 
+    def test_post_branch_init_hook_repr(self):
+        param_reprs = []
+        _mod_branch.Branch.hooks.install_named_hook('post_branch_init',
+            lambda params: param_reprs.append(repr(params)), None)
+        branch = self.make_branch('a')
+        self.assertLength(1, param_reprs)
+        param_repr = param_reprs[0]
+        self.assertStartsWith(param_repr, '<BranchInitHookParams of ')
+
     def test_post_switch_hook(self):
         from bzrlib import switch
         calls = []

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2010-06-29 16:21:13 +0000
+++ bzrlib/tests/test_bzrdir.py	2010-08-13 07:43:51 +0000
@@ -1401,3 +1401,13 @@
         self.assertIsInstance(params, RepoInitHookParams)
         self.assertTrue(hasattr(params, 'bzrdir'))
         self.assertTrue(hasattr(params, 'repository'))
+
+    def test_post_repo_init_hook_repr(self):
+        param_reprs = []
+        bzrdir.BzrDir.hooks.install_named_hook('post_repo_init',
+            lambda params: param_reprs.append(repr(params)), None)
+        self.make_repository('foo')
+        self.assertLength(1, param_reprs)
+        param_repr = param_reprs[0]
+        self.assertStartsWith(param_repr, '<RepoInitHookParams for ')
+

